nbformat: Base implementation of the Jupyter notebook format
============================================================

Description
-----------

This package contains the base implementation of the Jupyter Notebook
format, and Python APIs for working with notebooks.
